Examples
========

.. toctree::
    :maxdepth: 2

    examples/sample-data.ipynb
    examples/get-model-grid.ipynb
    examples/eos.ipynb
    examples/region-mask.ipynb
    examples/lateral-fill-idealized.ipynb
    examples/lateral-fill-model-grid.ipynb
    examples/pop_div_curl_xr_xgcm_metrics_compare.ipynb
